@@ -12,7 +12,7 @@ import re
 import click
 import urllib.parse as urlparse# type: ignore
 
-from .core import Queue, Empty, Task
+from .core import Queue, Empty, Task, CurrentTaskUnfinished
 
 from bravado.client import SwaggerClient
 
